% Auto-generated chapter 35 for muslim
% Hadiths in this chapter: 59

\hadithdefcmd{muslim}{5064}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، ح وَحَدَّثَنَاهُ يَحْيَى، بْنُ يَحْيَى أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، حَدَّثَنِي جُنْدَبُ بْنُ سُفْيَانَ، قَالَ شَهِدْتُ الأَضْحَى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَعْدُ أَنْ صَلَّى وَفَرَغَ مِنْ صَلاَتِهِ سَلَّمَ فَإِذَا هُوَ يَرَى لَحْمَ أَضَاحِيَّ قَدْ ذُبِحَتْ قَبْلَ أَنْ يَفْرُغَ مِنْ صَلاَتِهِ فَقَالَ ‏ "‏ مَنْ كَانَ ذَبَحَ أُضْحِيَّتَهُ قَبْلَ أَنْ يُصَلِّيَ - أَوْ نُصَلِّيَ - فَلْيَذْبَحْ مَكَانَهَا أُخْرَى وَمَنْ كَانَ لَمْ يَذْبَحْ فَلْيَذْبَحْ بِاسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{5064}\hadithtrans{Jundab b. Sufyan reported:I was with Allah's Messenger (ﷺ) on the day of 'Id al-Adha. While he had not returned after having offered (the Id prayer) and finished it, he saw the flesh of the sacrificial animals which had been slaughtered before he had completed the prayer. Thereupon he (the Holy Prophet) said: One who slaughtered his sacrificial animal before his prayer or our prayer ('Id), he should slaughter another one in its stead, and he who did not slaughter, he should slaughter by reciting the name of Allah}}
\hadithdefcmd{muslim}{5065}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، سَلاَّمُ بْنُ سُلَيْمٍ عَنِ الأَسْوَدِ، بْنِ قَيْسٍ عَنْ جُنْدَبِ بْنِ سُفْيَانَ، قَالَ شَهِدْتُ الأَضْحَى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَضَى صَلاَتَهُ بِالنَّاسِ نَظَرَ إِلَى غَنَمٍ قَدْ ذُبِحَتْ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيَذْبَحْ شَاةً مَكَانَهَا وَمَنْ لَمْ يَكُنْ ذَبَحَ فَلْيَذْبَحْ عَلَى اسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{5065}\hadithtrans{Jundab b. Sufyan reported:I was with Allah's Messenger (ﷺ) (on the occasion) of 'Id al-Adha. After he had completed the prayer with people, he found that the goats had been slaughtered, whereupon he said: He who slaughtered sacrificial animal before the prayer should slaughter a goat (again) in its stead and he who has not slaughtered he should slaughter it by reciting the name of Allah}}
\hadithdefcmd{muslim}{5066}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، أَبِي عُمَرَ عَنِ ابْنِ عُيَيْنَةَ، كِلاَهُمَا عَنِ الأَسْوَدِ بْنِ قَيْسٍ، بِهَذَا الإِسْنَادِ وَقَالاَ عَلَى اسْمِ اللَّهِ ‏.‏ كَحَدِيثِ أَبِي الأَحْوَصِ ‏.‏\hadithno{5066}\hadithtrans{This hadith has been narrated on the authority of al-Aswad b. Qais with the same chain of transmitters}}
\hadithdefcmd{muslim}{5067}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ، سَمِعَ جُنْدَبًا الْبَجَلِيَّ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمَ أَضْحًى ثُمَّ خَطَبَ فَقَالَ ‏ "‏ مَنْ كَانَ ذَبَحَ قَبْلَ أَنْ يُصَلِّيَ فَلْيُعِدْ مَكَانَهَا وَمَنْ لَمْ يَكُنْ ذَبَحَ فَلْيَذْبَحْ بِاسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{5067}\hadithtrans{Jundab al-Bajali reported:I saw Allah's Messenger (ﷺ) observing ('Id) prayer on the Day of Sacrifice (10th of Dhu'l-Hijja) and then delivering a sermon and he said: He who sacrificed the (animal) before offering ('Id) prayer, he should offer again in its stead, and he who did not sacrifice the animal should slaughter it by reciting the name of Allah}}
\hadithdefcmd{muslim}{5068}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5068}\hadithtrans{This hadith has been narrated on the authority of Shu'ba through another chain of transmitters}}
\hadithdefcmd{muslim}{5069}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ، قَالَ ضَحَّى خَالِي أَبُو بُرْدَةَ قَبْلَ الصَّلاَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عِنْدِي جَذَعَةً مِنَ الْمَعْزِ فَقَالَ ‏"‏ ضَحِّ بِهَا وَلاَ تَصْلُحُ لِغَيْرِكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ ضَحَّى قَبْلَ الصَّلاَةِ فَإِنَّمَا ذَبَحَ لِنَفْسِهِ وَمَنْ ذَبَحَ بَعْدَ الصَّلاَةِ فَقَدْ تَمَّ نُسُكُهُ وَأَصَابَ سُنَّةَ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{5069}\hadithtrans{Al-Bara' reported:My maternal uncle Abu Burda sacrificed his animal before ('Id) prayer. Thereupon Allah's Messenger (ﷺ) said: That is a goat (slaughtered for the sake of) flesh (and not as a sacrifice on the day of Adha). He said: I have a lamb of six months. Thereupon he said: Offer it as a sacrifice, but it will not justify for anyone except you, and then said: He who sacrificed (the animal) before ('Id) prayer, he in fact slaughtered it for his own self, and he who slaughtered after prayer, his ritual of sacrifice became complete and he in fact observed the religious practice of the Muslims}}
\hadithdefcmd{muslim}{5070}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ خَالَهُ أَبَا بُرْدَةَ بْنَ نِيَارٍ، ذَبَحَ قَبْلَ أَنْ يَذْبَحَ النَّبِيُّ، صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ هَذَا يَوْمٌ اللَّحْمُ فِيهِ مَكْرُوهٌ وَإِنِّي عَجَّلْتُ نَسِيكَتِي لأُطْعِمَ أَهْلِي وَجِيرَانِي وَأَهْلَ دَارِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعِدْ نُسُكًا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عِنْدِي عَنَاقَ لَبَنٍ هِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ ‏.‏ فَقَالَ ‏"‏ هِيَ خَيْرُ نَسِيكَتَيْكَ وَلاَ تَجْزِي جَذَعَةٌ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{5070}\hadithtrans{Al-Bara' b. 'Azib reported that his maternal'uncle Abu Burda b. Niyar sacrificed his animal earlier than the Prophet (ﷺ) had sacrificed. Thereupon he said:Apostle of Allah, it is the day of meat and it is not desirable (to have longing for it and not to make use of it immediately), so I hastened in offering my animal as a sacrifice, so that I might feed my family and neighbours and my kith and kin. Thereupon Allah's Messenger (ﷺ) said: Offer again your sacrifice. He said: Messenger of Allah, I have a small milch goat of less than one year, and that is better than two dry goats (from which only) meat (can be acquired). Thereupon he said: That is better than the two animals of sacrifice on your behalf, and the sacrifice of a goat, of less than six months shall not be accepted as a sacrifice on behalf of anyone after your (sacrifice)}}
\hadithdefcmd{muslim}{5071}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، بْنِ عَازِبٍ قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ فَقَالَ ‏ "‏ لاَ يَذْبَحَنَّ أَحَدٌ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ قَالَ فَقَالَ خَالِي يَا رَسُولَ اللَّهِ إِنَّ هَذَا يَوْمٌ اللَّحْمُ فِيهِ مَكْرُوهٌ ‏.‏ ثُمَّ ذَكَرَ بِمَعْنَى حَدِيثِ هُشَيْمٍ ‏.‏\hadithno{5071}\hadithtrans{Al-Bara' b. 'Azib reported:Allah's Messenger (ﷺ) delivered an address on the day (of Nahr) in which he said: None of you should offer sacrifice of animals until he has completed the ('Id) prayer. Thereupon my maternal uncle said: Messenger of Allah, it is the day of meat, so it is not desirable (to keep my family in the state of longing). The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5072}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَوَجَّهَ قِبْلَتَنَا وَنَسَكَ نُسُكَنَا فَلاَ يَذْبَحْ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ فَقَالَ خَالِي يَا رَسُولَ اللَّهِ قَدْ نَسَكْتُ عَنِ ابْنٍ لِي ‏.‏ فَقَالَ ‏"‏ ذَاكَ شَىْءٌ عَجَّلْتَهُ لأَهْلِكَ ‏"‏ ‏.‏ فَقَالَ إِنَّ عِنْدِي شَاةً خَيْرٌ مِنْ شَاتَيْنِ قَالَ ‏"‏ ضَحِّ بِهَا فَإِنَّهَا خَيْرُ نَسِيكَةٍ ‏"‏ ‏.‏\hadithno{5072}\hadithtrans{Al-Bara' reported Allah's Messenger (ﷺ) having said:He who observes prayer like our prayer and turns his face towards our Qibla (in prayer) and who offers sacrifices (of animals) as we do, he must not slaughter the (animal as a sacrifice) until he has completed the prayer. Thereupon my maternal uncle said: Messenger of Allah, I have sacrificed the animal on behalf of my son. The Messenger of Allah (ﷺ) said: This is the thing in which you have made haste for your family. He said: I have a goat with me better than two goats. Thereupon he said: Sacrifice it for that is the best}}
\hadithdefcmd{muslim}{5073}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ الإِيَامِيِّ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ بِهِ فِي يَوْمِنَا هَذَا نُصَلِّي ثُمَّ نَرْجِعُ فَنَنْحَرُ فَمَنْ فَعَلَ ذَلِكَ فَقَدْ أَصَابَ سُنَّتَنَا وَمَنْ ذَبَحَ فَإِنَّمَا هُوَ لَحْمٌ قَدَّمَهُ لأَهْلِهِ لَيْسَ مِنَ النُّسُكِ فِي شَىْءٍ ‏"‏ ‏.‏ وَكَانَ أَبُو بُرْدَةَ بْنُ نِيَارٍ قَدْ ذَبَحَ فَقَالَ عِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ فَقَالَ ‏"‏ اذْبَحْهَا وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{5073}\hadithtrans{Al-Bara' b. 'Azib reported Allah's Messenger (ﷺ) having said:The first (act) with which we started our day (the day of 'Id-ul Adha) was that we offered prayer. We then returned and sacrificed the animals and he who did that in fact adhered to our Sunnah (practice). And he who slaughtered the (animal on that day before the 'Id prayer), for him (the slaughtering of animal was directed to the acquiring of) meat for his family, and there is nothing of the sort of sacrifice in it. It was Abu Burda b. Niyar who had slaughtered (the animal before the 'Id prayer). He said: I have a small lamb, of less than one year, but better than that of more than a year. Thereupon Allah's Messenger (ﷺ) qaid: Sacrifice it, but it will not suffice (as a sacrifice) for anyone after you}}
\hadithdefcmd{muslim}{5074}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ، سَمِعَ الشَّعْبِيَّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{5074}\hadithtrans{A hadith like this has been narrated on the authority of al-Bara' b. 'Azib through another chain of transmitters}}
\hadithdefcmd{muslim}{5075}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، كِلاَهُمَا عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَوْمِ النَّحْرِ بَعْدَ الصَّلاَةِ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{5075}\hadithtrans{al-Bara' b. 'Azib reported:Allah's Messenger (ﷺ) addressed us on the day of Nahr after the ('Id) prayer. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5076}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا أَبُو النُّعْمَانِ، عَارِمُ بْنُ الْفَضْلِ حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنِ الشَّعْبِيِّ، حَدَّثَنِي الْبَرَاءُ، بْنُ عَازِبٍ قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَوْمِ نَحْرٍ فَقَالَ ‏"‏ لاَ يُضَحِّيَنَّ أَحَدٌ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ قَالَ رَجُلٌ عِنْدِي عَنَاقُ لَبَنٍ هِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ قَالَ ‏"‏ فَضَحِّ بِهَا وَلاَ تَجْزِي جَذَعَةٌ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{5076}\hadithtrans{Al-Bara' b. 'Azib reported:Allah's Messenger (ﷺ) addressed us on the day of Nahr and said: None should sacrifice the animal unless he has completed the ('Id) prayer. A person said: I have a milch goat of less than one year, better than two fat goats. Thereupon he said: Sacrifice it, and no goat of less than a year of age will be accepted as sacrifice after you}}
\hadithdefcmd{muslim}{5077}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ أَبِي جُحَيْفَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ ذَبَحَ أَبُو بُرْدَةَ قَبْلَ الصَّلاَةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْدِلْهَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ لَيْسَ عِنْدِي إِلاَّ جَذَعَةٌ - قَالَ شُعْبَةُ وَأَظُنُّهُ قَالَ - وَهِيَ خَيْرٌ مِنْ مُسِنَّةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْعَلْهَا مَكَانَهَا وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{5077}\hadithtrans{Al-Bara' b. 'Azib reported that Abu Burda slaughtered the animal as a sacrifice before the ('Id) prayer. Thereupon Allah's Apostle (ﷺ) said:Offer a substitute for it (since it does not absolve you of the responsibility of sacrifice). Thereupon he said: Allah's Messenger. I have nothing with me but a goat of less than six months. Shu'ba (one of the narrators) said: I think he (al-Bara' b. 'Azib also) said: And it is better than a goat of one year. Thereupon Allah's Messenger (ﷺ) said: Make it a substitute for that (and sacrifice it), but it will not suffice for anyone (as a sacrifice) after you}}
\hadithdefcmd{muslim}{5078}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرِ الشَّكَّ فِي قَوْلِهِ هِيَ خَيْرٌ مِنْ مُسِنَّةٍ ‏.‏\hadithno{5078}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters, but did not mention tht doubt (expressed in his statement) That is (the goat of less than a year) is better than a goat of more than one year}}
\hadithdefcmd{muslim}{5079}{وَحَدَّثَنِي يَحْيَى بْنُ أَيُّوبَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لِعَمْرٍو - قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ ‏ "‏ مَنْ كَانَ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيُعِدْ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا يَوْمٌ يُشْتَهَى فِيهِ اللَّحْمُ ‏.‏ وَذَكَرَ هَنَةً مِنْ جِيرَانِهِ كَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَدَّقَهُ قَالَ وَعِنْدِي جَذَعَةٌ هِيَ أَحَبُّ إِلَىَّ مِنْ شَاتَىْ لَحْمٍ أَفَأَذْبَحُهَا قَالَ فَرَخَّصَ لَهُ فَقَالَ لاَ أَدْرِي أَبَلَغَتْ رُخْصَتُهُ مَنْ سِوَاهُ أَمْ لاَ قَالَ وَانْكَفَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى كَبْشَيْنِ فَذَبَحَهُمَا فَقَامَ النَّاسُ إِلَى غُنَيْمَةٍ فَتَوَزَّعُوهَا ‏.‏ أَوْ قَالَ فَتَجَزَّعُوهَا ‏.‏\hadithno{5079}\hadithtrans{Anas (b. Malik) reported Allah's Messenger (ﷺ) having said on the day of Nahr (Sacrifice):He who slaughtered (the animal as a sacrifice) before the ('Id) prayer. should repeat it (i. e. offer another animal). Thereupon a person stood up and said: Messenger of Allah, that is the day when meat is much desired, and he also made a mention of the need of his neighbour, and perhaps Allah's Messenger (ﷺ) attested it. He (the person who had sacrificed the animal before the 'Id prayer) said: I have a goat of less than one year of age with me and I like it more than two fleshy goats; should I offer it as a sacrifice? He permitted him to do so. He (the narrator) said: I do not know whether this permission was granted to anyone else besides him or not. Allah's Messenger (ﷺ) then turned towards two rams. and he slaughtered them, and the people' came to the goats and got them distributed amongst themselves (for offering them as sacrifice)}}
\hadithdefcmd{muslim}{5080}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، وَهِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى ثُمَّ خَطَبَ فَأَمَرَ مَنْ كَانَ ذَبَحَ قَبْلَ الصَّلاَةِ أَنْ يُعِيدَ ذِبْحًا ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{5080}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) offered the 'Id prayer and then delivered the sermon giving the command:He who slaughtered the animal before prayer should slaughter (another animal as a sacrifice). The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5081}{وَحَدَّثَنِي زِيَادُ بْنُ يَحْيَى الْحَسَّانِيُّ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ وَرْدَانَ - حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ أَضْحًى - قَالَ - فَوَجَدَ رِيحَ لَحْمٍ فَنَهَاهُمْ أَنْ يَذْبَحُوا قَالَ ‏ "‏ مَنْ كَانَ ضَحَّى فَلْيُعِدْ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِهِمَا ‏.‏\hadithno{5081}\hadithtrans{Anas b. Malik reported:Allah's Messenger (ﷺ) addressed us on the day of 'Id al-Adha. He smelt the odour of flesh and he prohibited thern from slaughtering (the animals before the 'Id prayer), saying: He who slaughtered the animals (before the 'Id prayer) should do that again (as it is not valid as a sacrifice)}}
\hadithdefcmd{muslim}{5082}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَذْبَحُوا إِلاَّ مُسِنَّةً إِلاَّ أَنْ يَعْسُرَ عَلَيْكُمْ فَتَذْبَحُوا جَذَعَةً مِنَ الضَّأْنِ ‏"‏ ‏.‏\hadithno{5082}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:Sacrifice only a grown-up animal, unless it is difficult for you, in which case sacrifice a ram (of even less than a year, but more than six months' age)}}
\hadithdefcmd{muslim}{5083}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ بِالْمَدِينَةِ فَتَقَدَّمَ رِجَالٌ فَنَحَرُوا وَظَنُّوا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ نَحَرَ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم مَنْ كَانَ نَحَرَ قَبْلَهُ أَنْ يُعِيدَ بِنَحْرٍ آخَرَ وَلاَ يَنْحَرُوا حَتَّى يَنْحَرَ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{5083}\hadithtrans{Jabir b. 'Abdullah reported:Allah's Messenger (ﷺ) led us in the 'Id prayer in Medina on the Day of Sacrifice. Some persons slaughtered their animals ahead of him under the impression that Allah's Apostle (ﷺ) had-already offered sacrifice. Thereupon Allah's Apostle (ﷺ) said: Those who had slaughtered their animals ahead of him should slaughter the other ones in their stead. And they should not sacrifice the animal before Allah's Messenger (ﷺ) had sacrificed (his animal)}}
\hadithdefcmd{muslim}{5084}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهُ غَنَمًا يَقْسِمُهَا عَلَى أَصْحَابِهِ ضَحَايَا فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ ضَحِّ بِهِ أَنْتَ ‏"‏ ‏.‏ قَالَ قُتَيْبَةُ عَلَى صَحَابَتِهِ ‏.‏\hadithno{5084}\hadithtrans{Uqba b. 'Amir reported that Allah's Messenger (ﷺ) gave the gifts of goats to be distributed amongst his Companions. They sacrificed them, but a lamb of one year of age was left. (Someone) made a mention of that to the Messenger of Allah (ﷺ), whereupon he said:You sacrifice it}}
\hadithdefcmd{muslim}{5085}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ بَعْجَةَ الْجُهَنِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِينَا ضَحَايَا فَأَصَابَنِي جَذَعٌ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ أَصَابَنِي جَذَعٌ ‏.‏ فَقَالَ ‏ "‏ ضَحِّ بِهِ ‏"‏ ‏.‏\hadithno{5085}\hadithtrans{Amir al-Juhani reported:Allah's Messenger (ﷺ) distributed sacrificial animals (amongst us for sacrificing them on 'Id al-Adha). So we sacrificed them. There fell to my lot a lamb of less than one year I said: Allah's Messenger, there has fallen to my lot a lamb (Jadha'a), whereupon he said: Sacrifice that}}
\hadithdefcmd{muslim}{5086}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ حَسَّانَ - أَخْبَرَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، أَخْبَرَنِي بَعْجَةُ بْنُ عَبْدِ، اللَّهِ أَنَّ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَسَمَ ضَحَايَا بَيْنَ أَصْحَابِهِ ‏.‏ بِمِثْلِ مَعْنَاهُ ‏.‏\hadithno{5086}\hadithtrans{This hadith has been transmitted on the authority of 'Uqba b. 'Amir al-Juhan with a slight change of wording}}
\hadithdefcmd{muslim}{5087}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ ضَحَّى النَّبِيُّ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ ذَبَحَهُمَا بِيَدِهِ وَسَمَّى وَكَبَّرَ وَوَضَعَ رِجْلَهُ عَلَى صِفَاحِهِمَا ‏.‏\hadithno{5087}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) sacrificed with his own hands two horned rams which were white with black markings reciting the name of Allah and glorifying Him (saying Allah-o-Akbar). He placed his foot on their sides (while sacrificing)}}
\hadithdefcmd{muslim}{5088}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ قَالَ وَرَأَيْتُهُ يَذْبَحُهُمَا بِيَدِهِ وَرَأَيْتُهُ وَاضِعًا قَدَمَهُ عَلَى صِفَاحِهِمَا قَالَ وَسَمَّى وَكَبَّرَ ‏.‏\hadithno{5088}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) sacrificed two horned rams of white colour with black markings over them. He also stated:I saw him sacrificing them with his own hand and saw him placing his foot on their sides, and recited the name of Allah and Glorified Him}}
\hadithdefcmd{muslim}{5089}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي قَتَادَةُ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏ قَالَ قُلْتُ آنْتَ سَمِعْتَهُ مِنْ أَنَسٍ قَالَ نَعَمْ ‏.‏\hadithno{5089}\hadithtrans{Shu'ba reported:Qatada informed me that he had heard Anas saying that Allah's Messenger (may peace be npon him) sacrificed (the horned rams) and like that. I said: Did you (Qatada) hear from Anas? He said. Yes}}
\hadithdefcmd{muslim}{5090}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ وَيَقُولُ ‏ "‏ بِاسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ ‏"‏ ‏.‏\hadithno{5090}\hadithtrans{This hadith has been transmitted on the authority of Anas with a slight variation of wording}}
\hadithdefcmd{muslim}{5091}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ قَالَ حَيْوَةُ أَخْبَرَنِي أَبُو صَخْرٍ، عَنْ يَزِيدَ بْنِ قُسَيْطٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِكَبْشٍ أَقْرَنَ يَطَأُ فِي سَوَادٍ وَيَبْرُكُ فِي سَوَادٍ وَيَنْظُرُ فِي سَوَادٍ فَأُتِيَ بِهِ لِيُضَحِّيَ بِهِ فَقَالَ لَهَا ‏"‏ يَا عَائِشَةُ هَلُمِّي الْمُدْيَةَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اشْحَذِيهَا بِحَجَرٍ ‏"‏ ‏.‏ فَفَعَلَتْ ثُمَّ أَخَذَهَا وَأَخَذَ الْكَبْشَ فَأَضْجَعَهُ ثُمَّ ذَبَحَهُ ثُمَّ قَالَ ‏"‏ بِاسْمِ اللَّهِ اللَّهُمَّ تَقَبَّلْ مِنْ مُحَمَّدٍ وَآلِ مُحَمَّدٍ وَمِنْ أُمَّةِ مُحَمَّدٍ ‏"‏ ‏.‏ ثُمَّ ضَحَّى بِهِ ‏.‏\hadithno{5091}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) commanded that a ram with black legs, black belly and black (circles) round the eyes should be brought to him, so that he should sacrifice it. He said to 'A'isha:Give me the large knife, and then said: Sharpen it on a stone. She did that. He then took it (the knife) and then the ram; he placed it on the ground and then sacrificed it, saying: Bismillah, Allah-humma Taqabbal min Muhammadin wa Al-i-Muhammadin, wa min Ummati Muhammadin (In the name of Allah," O Allah, accept [this sacrifice] on behalf of Muhammad and the family of Muhammad and the Umma of Muhammad}}
\hadithdefcmd{muslim}{5092}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي أَبِي، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا وَلَيْسَتْ مَعَنَا مُدًى قَالَ صلى الله عليه وسلم ‏"‏ أَعْجِلْ أَوْ أَرْنِي مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ لَيْسَ السِّنَّ وَالظُّفُرَ وَسَأُحَدِّثُكَ أَمَّا السِّنُّ فَعَظْمٌ وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏ ‏.‏ قَالَ وَأَصَبْنَا نَهْبَ إِبِلٍ وَغَنَمٍ فَنَدَّ مِنْهَا بَعِيرٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الإِبِلِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَإِذَا غَلَبَكُمْ مِنْهَا شَىْءٌ فَاصْنَعُوا بِهِ هَكَذَا ‏"‏ ‏.‏\hadithno{5092}\hadithtrans{Rafi' b. Khadij is reported to have said:Allah's Messenger, we are going to encounter the enemy tomorrow, but we have no knives with us. Thereupon Allah's Messenger (ﷺ) said: Make haste or be careful (in making arrangements for procuring knives) which would let the blood flow (and along with it) the name of Allah is also to be recited. Then eat, but not the tooth or nail. And I am going to tell you why it is not permissible to slaughter the animal with the help of tooth and bone; and as for the nail. it is a bone, and the bone is the knife of Abyssinians. He (the narrator) said: There fell to our lot as spoils of war camels and goats, and one of the camels among them became wild. A person (amongst usl struck It with an arrow which brought it under control. whereupon Allah's Messenger (ﷺ) said: This camel became wild like wild animals, so if you find any animal getting wild, you do the same with that}}
\hadithdefcmd{muslim}{5093}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ مِنْ تِهَامَةَ فَأَصَبْنَا غَنَمًا وَإِبِلاً فَعَجِلَ الْقَوْمُ فَأَغْلَوْا بِهَا الْقُدُورَ فَأَمَرَ بِهَا فَكُفِئَتْ ثُمَّ عَدَلَ عَشْرًا مِنَ الْغَنَمِ بِجَزُورٍ ‏.‏ وَذَكَرَ بَاقِيَ الْحَدِيثِ كَنَحْوِ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ ‏.‏\hadithno{5093}\hadithtrans{Rafi' b. Khadij reported:While we were with Allah's Messenger (may peace he upon him) in Dhu'I-Hulaifa in Tihama, we got hold of goats and camels. Some persons (amongst us) made haste and boiled (the flesh of goats and camels) in their earthen pots. He then commanded and these were turned over; then he equalised ten goats for a camel. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5094}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ، عَنْ جَدِّهِ، رَافِعٍ ثُمَّ حَدَّثَنِيهِ عُمَرُ بْنُ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ، رِفَاعَةَ بْنِ رَافِعِ بْنِ خَدِيجٍ عَنْ جَدِّهِ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا وَلَيْسَ مَعَنَا مُدًى فَنُذَكِّي بِاللِّيطِ وَذَكَرَ الْحَدِيثَ بِقِصَّتِهِ وَقَالَ فَنَدَّ عَلَيْنَا بَعِيرٌ مِنْهَا فَرَمَيْنَاهُ بِالنَّبْلِ حَتَّى وَهَصْنَاهُ ‏.‏\hadithno{5094}\hadithtrans{Rafi' b. Khadij reported from his grandfather that he said:Allah's Messenger, we are going to encounter the enemy tomorrow, but we do not have long knives with us, should we then slaughter them with the peel of the reed? The rest of the hadith is the same. (And at the end the words are):" A camel became wild (and got out of our control). We attacked it with arrows until we made it fall down}}
\hadithdefcmd{muslim}{5095}{وَحَدَّثَنِيهِ الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، بِهَذَا الإِسْنَادِ الْحَدِيثَ إِلَى آخِرِهِ بِتَمَامِهِ وَقَالَ فِيهِ وَلَيْسَتْ مَعَنَا مُدًى أَفَنَذْبَحُ بِالْقَصَبِ\hadithno{5095}\hadithtrans{This hadith has been narrated on the authority of Sa'id b. Masruq with the same chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{5096}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ بْنِ عَبْدِ الْحَمِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا وَلَيْسَ مَعَنَا مُدًى وَسَاقَ الْحَدِيثَ وَلَمْ يَذْكُرْ فَعَجِلَ الْقَوْمُ فَأَغْلَوْا بِهَا الْقُدُورَ فَأَمَرَ بِهَا فَكُفِئَتْ وَذَكَرَ سَائِرَ الْقِصَّةِ ‏.‏\hadithno{5096}\hadithtrans{Rafi' b. Khadij reported that he said:Allah's Messenger, we are going to encounter the enemy tomorrow. and we do not have large knives with us. The rest of the hadith is the same, but no mention is made of this:" The people hastened and they boiled (flesh) in the earthen pots. He (the Holy Prophet), cammanded and these were turned over and the narrator narrated the whole event}}
\hadithdefcmd{muslim}{5097}{حَدَّثَنِي عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي عُبَيْدٍ، قَالَ شَهِدْتُ الْعِيدَ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ وَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَأْكُلَ مِنْ لُحُومِ نُسُكِنَا بَعْدَ ثَلاَثٍ ‏.‏\hadithno{5097}\hadithtrans{Abu Ubaid reported:I was with 'Ali b. Abi Talib on the occasion of the 'Id day. He started with the 'Id prayer before delivering the sermon, and said: Allah's Messenger (ﷺ) forbade us to eat the flesh of our sacrificial animals beyond three days}}
\hadithdefcmd{muslim}{5098}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ أَنَّهُ شَهِدَ الْعِيدَ مَعَ عُمَرَ بْنِ الْخَطَّابِ قَالَ ثُمَّ صَلَّيْتُ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ - قَالَ - فَصَلَّى لَنَا قَبْلَ الْخُطْبَةِ ثُمَّ خَطَبَ النَّاسَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَهَاكُمْ أَنْ تَأْكُلُوا لُحُومَ نُسُكِكُمْ فَوْقَ ثَلاَثِ لَيَالٍ فَلاَ تَأْكُلُوا ‏.‏\hadithno{5098}\hadithtrans{Abu 'Ubaid, the freed slave of Ibn Azhar, reported that he said 'Id (prayer) with Umar b. al-Khattab, and then said the 'Id (prayer) with 'Ali b. Abu Talib. He (the narrator further) reported:He led us in prayer before delivering the sermon and then addressed the people saying: Allah's Messenger (ﷺ) has forbidden you to eat the flesh of your sacrificial animals beyond three nights, so do not eat that}}
\hadithdefcmd{muslim}{5099}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، ح وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5099}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{5100}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَأْكُلْ أَحَدٌ مِنْ لَحْمِ أُضْحِيَّتِهِ فَوْقَ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏\hadithno{5100}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) having said:None of you should eat the flesh of his sacrificial animal beyond three days}}
\hadithdefcmd{muslim}{5101}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{5101}\hadithtrans{This hadith has been narrated on the authority of Ibn Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{5102}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا وَقَالَ عَبْدٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُؤْكَلَ لُحُومُ الأَضَاحِي بَعْدَ ثَلاَثٍ ‏.‏ قَالَ سَالِمٌ فَكَانَ ابْنُ عُمَرَ لاَ يَأْكُلُ لُحُومَ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ ‏.‏ وَقَالَ ابْنُ أَبِي عُمَرَ بَعْدَ ثَلاَثٍ ‏.‏\hadithno{5102}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) forbade that the flesh of sacrificial animals be eaten beyond three (days) Salim (son of Ibn Umar) said:Ibn 'Umar did not eat the flesh of the sacrificial animals beyond three (days). Ibn Abu 'Umar said:" Beyond three days}}
\hadithdefcmd{muslim}{5103}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي بَكْرٍ عَنْ عَبْدِ اللَّهِ بْنِ وَاقِدٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثٍ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ فَذَكَرْتُ ذَلِكَ لِعَمْرَةَ فَقَالَتْ صَدَقَ سَمِعْتُ عَائِشَةَ تَقُولُ دَفَّ أَهْلُ أَبْيَاتٍ مِنْ أَهْلِ الْبَادِيَةِ حِضْرَةَ الأَضْحَى زَمَنَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادَّخِرُوا ثَلاَثًا ثُمَّ تَصَدَّقُوا بِمَا بَقِيَ ‏"‏ ‏.‏ فَلَمَّا كَانَ بَعْدَ ذَلِكَ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ يَتَّخِذُونَ الأَسْقِيَةَ مِنْ ضَحَايَاهُمْ وَيَحْمِلُونَ مِنْهَا الْوَدَكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا نَهَيْتَ أَنْ تُؤْكَلَ لُحُومُ الضَّحَايَا بَعْدَ ثَلاَثٍ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا نَهَيْتُكُمْ مِنْ أَجْلِ الدَّافَّةِ الَّتِي دَفَّتْ فَكُلُوا وَادَّخِرُوا وَتَصَدَّقُوا ‏"‏ ‏.‏\hadithno{5103}\hadithtrans{Abdullah b. Waqid reported:Allah's Messenger (ﷺ) forbade (people) to cat the flesh of sacrificed animals beyond three days. Abdullah b. Abu Bakr said, I made a mention of that to 'Amra, whereupon she said: He has told the truth, for I heard 'A'isha say: The poor among the people of the desert come (to the towns) on the occasion of Id al-Adha during the lifetime of Allah's Messenger (ﷺ). Upon this Allah's Messenger (ﷺ) said: Retain with you (the flesh) sufficing for three (days), and whatever is left out of that give in charity. After this. they (the Muslims) said: Allah's Messenger, the people make waterskins with the (hides) of their sacrificed animals and they melt fat out of them. Thereupon he said. What the then? They said: You forbade (us) to eat the flesh of sacrificial animals beyond threoq (days), whereupon he said: I forbade you for those (poor persons) who flocked (to the towns on this occasion for getting meat) but now when (this situation has improved) you may eat, preserve and give -in charity}}
\hadithdefcmd{muslim}{5104}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ أَكْلِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثٍ ثُمَّ قَالَ بَعْدُ ‏ "‏ كُلُوا وَتَزَوَّدُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{5104}\hadithtrans{Jabir reported that Allah's Apostle (ﷺ) forbade eating of the flesh of sacrificed animals beyond three (days). but afterwards said:Eat, make a provision, and keep it}}
\hadithdefcmd{muslim}{5105}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنَا عَطَاءٌ، قَالَ سَمِعْتُ جَابِرَ بْنَ، عَبْدِ اللَّهِ يَقُولُ كُنَّا لاَ نَأْكُلُ مِنْ لُحُومِ بُدْنِنَا فَوْقَ ثَلاَثِ مِنًى فَأَرْخَصَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ كُلُوا وَتَزَوَّدُوا ‏"‏ ‏.‏ قُلْتُ لِعَطَاءٍ قَالَ جَابِرٌ حَتَّى جِئْنَا الْمَدِينَةَ قَالَ نَعَمْ ‏.‏\hadithno{5105}\hadithtrans{Jabir b. Abdullah reported:We did not eat the flesh of our sacrificial animals beyond three days in Mina. Then Allah's Messenger (ﷺ) permitted us saying: Eat and make it a provision (for journey). I asked 'Ata' whether Jabir had also said: Till we came to Medina. He said: Yes}}
\hadithdefcmd{muslim}{5106}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا لاَ نُمْسِكُ لُحُومَ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَتَزَوَّدَ مِنْهَا وَنَأْكُلَ مِنْهَا ‏.‏ يَعْنِي فَوْقَ ثَلاَثٍ ‏.‏\hadithno{5106}\hadithtrans{Jabir b. 'Abdullah reported:We did not eat the flesh of sacrificed animals beyond three (days), but then Allah's Messenger (ﷺ) commanded us to make it a provision for journey and cat it (beyond three days)}}
\hadithdefcmd{muslim}{5107}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَتَزَوَّدُهَا إِلَى الْمَدِينَةِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5107}\hadithtrans{Jabir reported:We made provision (out of the flesh of sacrificed animals for our journey) to Medina during the lifetime of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{5108}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي، نَضْرَةَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَهْلَ الْمَدِينَةِ لاَ تَأْكُلُوا لُحُومَ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ ‏"‏ ‏.‏ وَقَالَ ابْنُ الْمُثَنَّى ثَلاَثَةِ أَيَّامٍ ‏.‏ فَشَكَوْا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ لَهُمْ عِيَالاً وَحَشَمًا وَخَدَمًا فَقَالَ ‏"‏ كُلُوا وَأَطْعِمُوا وَاحْبِسُوا أَوِ ادَّخِرُوا ‏"‏ ‏.‏ قَالَ ابْنُ الْمُثَنَّى شَكَّ عَبْدُ الأَعْلَى ‏.‏\hadithno{5108}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) having said:O people of Medina, do not eat the flesh of sacrificed animals beyond three days. Ibn al-Muthanni said: Three days. They (the Companions of the Holy Prophet) complained to the Messenger of Allah (may peace he upon him) that they had children and servants of theirs (to feed), whereupon he said: Eat, and feed others, and store, and make it a provision of food}}
\hadithdefcmd{muslim}{5109}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو عَاصِمٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، بْنِ الأَكْوَعِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ ضَحَّى مِنْكُمْ فَلاَ يُصْبِحَنَّ فِي بَيْتِهِ بَعْدَ ثَالِثَةٍ شَيْئًا ‏"‏ ‏.‏ فَلَمَّا كَانَ فِي الْعَامِ الْمُقْبِلِ قَالُوا يَا رَسُولَ اللَّهِ نَفْعَلُ كَمَا فَعَلْنَا عَامَ أَوَّلَ فَقَالَ ‏"‏ لاَ إِنَّ ذَاكَ عَامٌ كَانَ النَّاسُ فِيهِ بِجَهْدٍ فَأَرَدْتُ أَنْ يَفْشُوَ فِيهِمْ ‏"‏ ‏.‏\hadithno{5109}\hadithtrans{Salama b. al-Akwa' reported Allah's Messenger (way peace be upon him) having said:He who sacrifices (animal) among you nothing should be left in his house (out of its flesh) on the morning of the third day. When it was the next year they (his Companions) said: Should we do this year as we did daring the previous year? Thereupon he said: Don't do that, for that was a year when the people were hard pressed (on account of poverty). so I wanted that the (flesh) might be distributed amongst them}}
\hadithdefcmd{muslim}{5110}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ أَبِي، الزَّاهِرِيَّةِ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ ثَوْبَانَ، قَالَ ذَبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَحِيَّتَهُ ثُمَّ قَالَ ‏ "‏ يَا ثَوْبَانُ أَصْلِحْ لَحْمَ هَذِهِ ‏"‏ ‏.‏ فَلَمْ أَزَلْ أُطْعِمُهُ مِنْهَا حَتَّى قَدِمَ الْمَدِينَةَ ‏.‏\hadithno{5110}\hadithtrans{Thauban reported that Allah's Messenger (way peace be upon him) slaughtered his sacrificial animal and then said:Thauban, make his meat usable (for journey), and I continuously served him that until he arrived in Medina}}
\hadithdefcmd{muslim}{5111}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، رَافِعٍ قَالاَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، كِلاَهُمَا عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5111}\hadithtrans{This hadith has been narrated on the authority of Mu'awiya b. Salih with the same chain of transmitters}}
\hadithdefcmd{muslim}{5116}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ فَرَعَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏ زَادَ ابْنُ رَافِعٍ فِي رِوَايَتِهِ وَالْفَرَعُ أَوَّلُ النِّتَاجِ كَانَ يُنْتَجُ لَهُمْ فَيَذْبَحُونَهُ ‏.‏\hadithno{5116}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:(The sacrifice of Fara' and 'Atira) has no (sanction in Islam). Ibn Rafi' made this addition in his narration that Fara' means the first-born young one of a camel}}
\hadithdefcmd{muslim}{5117}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ أَبُو بَكْرٍ عَنْ أَبِي سِنَانٍ، وَقَالَ ابْنُ الْمُثَنَّى، عَنْ ضِرَارِ بْنِ مُرَّةَ، عَنْ مُحَارِبٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا ضِرَارُ بْنُ مُرَّةَ، أَبُو سِنَانٍ عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ فَأَمْسِكُوا مَا بَدَا لَكُمْ وَنَهَيْتُكُمْ عَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ فَاشْرَبُوا فِي الأَسْقِيَةِ كُلِّهَا وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏\hadithno{5117}\hadithtrans{Abdullah b. Buraida reported on the authority of his father that Allah's Messenger (ﷺ) said this:I prohibited you from visiting the graves, but (now) you may visit them, and I prohibited you (from eating) the flesh of sacrific- ed animals beyond three days, but now keep it as long as you like. I prohibited you from the use of Nabidh except (that preoared) in dry waterskins. Now drink (Nabidh prepared in any utensil), but do not drink when it becomes intoxicant}}
\hadithdefcmd{muslim}{5118}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ، بْنِ مَرْثَدٍ عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُنْتُ نَهَيْتُكُمْ ‏"‏ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ أَبِي سِنَانٍ ‏.‏\hadithno{5118}\hadithtrans{Ibn Buraida, on the authority of his father, reported Allah's Messenger (ﷺ) having said this:I used to forbid you. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5119}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، بْنِ عَوْفٍ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَتِ الْعَشْرُ وَأَرَادَ أَحَدُكُمْ أَنْ يُضَحِّيَ فَلاَ يَمَسَّ مِنْ شَعَرِهِ وَبَشَرِهِ شَيْئًا ‏"‏ ‏.‏ قِيلَ لِسُفْيَانَ فَإِنَّ بَعْضَهُمْ لاَ يَرْفَعُهُ قَالَ لَكِنِّي أَرْفَعُهُ ‏.‏\hadithno{5119}\hadithtrans{Umm Salama reported Allah's Messenger (ﷺ) having said this:When any one of you intending to sacrifice the animal enters in the month (of Dhu'l-Hijja) he should not get his hair or nails touched (cut). It was said to Sufyan that some of the (scholars) did not deem this hadith to be Maffu'. He said: But I deem it as Marfu' (i. e. chain of narration traceable right up to the Holy Prophet)}}
\hadithdefcmd{muslim}{5120}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ حُمَيْدِ بْنِ، عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، تَرْفَعُهُ قَالَ ‏ "‏ إِذَا دَخَلَ الْعَشْرُ وَعِنْدَهُ أُضْحِيَّةٌ يُرِيدُ أَنْ يُضَحِّيَ فَلاَ يَأْخُذَنَّ شَعْرًا وَلاَ يَقْلِمَنَّ ظُفُرًا ‏"‏ ‏.‏\hadithno{5120}\hadithtrans{Umm Salama reported Allah's Apostle (ﷺ) as saying:If anyone of you intends to offer sacrifice he should not get his hair cut or nails trimmed}}
\hadithdefcmd{muslim}{5121}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنِي يَحْيَى بْنُ كَثِيرٍ الْعَنْبَرِيُّ أَبُو غَسَّانَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عُمَرَ بْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمْ هِلاَلَ ذِي الْحِجَّةِ وَأَرَادَ أَحَدُكُمْ أَنْ يُضَحِّيَ فَلْيُمْسِكْ عَنْ شَعْرِهِ وَأَظْفَارِهِ ‏"‏ ‏.‏\hadithno{5121}\hadithtrans{Umm Salama reported (these words) directly from Allah's Messenger (ﷺ):If anyone has in his possession a sacrificial animal to offer as a sacrifice (on 'Id al-Adha), he should not get his hair cut and nails trimmed after he has entered the first days of Dhu'l Hijja}}
\hadithdefcmd{muslim}{5122}{حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا عَمْرُو بْنُ مُسْلِمِ بْنِ عَمَّارٍ اللَّيْثِيُّ، قَالَ كُنَّا فِي الْحَمَّامِ قُبَيْلَ الأَضْحَى فَاطَّلَى فِيهِ نَاسٌ فَقَالَ بَعْضُ أَهْلِ الْحَمَّامِ إِنَّ سَعِيدَ بْنَ الْمُسَيَّبِ يَكْرَهُ هَذَا أَوْ يَنْهَى عَنْهُ فَلَقِيتُ سَعِيدَ بْنَ الْمُسَيَّبِ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ يَا ابْنَ أَخِي هَذَا حَدِيثٌ قَدْ نُسِيَ وَتُرِكَ حَدَّثَتْنِي أُمُّ سَلَمَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ مُعَاذٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو ‏.‏\hadithno{5122}\hadithtrans{Amr b. Muslim b. 'Ammar al-Laithi reported:While we were in a bathroom just before 'Id al-Adha some of the persons tried to remove the hair with the help of hair-removing chemicals. Thereupon some of the people owning the bath (or some of the people sitting therein) said that Sa'id b. Musayyib did not approve of it, or he prohibited it. Then I met Sa'id b. Musayyib and made a mention of that to him, whereupon he said: O my nephew, this is the hadith which has been forgotten, and abandoned. Umm Salama, the wife of Allah's Apostle (ﷺ), narrated to me Allah's Messenger (ﷺ) having said as narrated above}}
\hadithdefcmd{muslim}{5123}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَخِي ابْنِ وَهْبٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ، أَخْبَرَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ عُمَرَ، بْنِ مُسْلِمٍ الْجُنْدَعِيِّ أَنَّ ابْنَ الْمُسَيَّبِ، أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ ‏.‏ وَذَكَرَ النَّبِيَّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِهِمْ ‏.‏\hadithno{5123}\hadithtrans{Amr b. Muslim al-Jundani reported that Ibn Musayyib had told him that it was Umm Salama, the wife of Allah's Apostle (ﷺ), who had informed him of that as narrated above}}
\hadithdefcmd{muslim}{5124}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَسُرَيْجُ بْنُ يُونُسَ، كِلاَهُمَا عَنْ مَرْوَانَ، قَالَ زُهَيْرٌ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، حَدَّثَنَا مَنْصُورُ بْنُ حَيَّانَ، حَدَّثَنَا أَبُو الطُّفَيْلِ، عَامِرُ بْنُ وَاثِلَةَ قَالَ كُنْتُ عِنْدَ عَلِيِّ بْنِ أَبِي طَالِبٍ فَأَتَاهُ رَجُلٌ فَقَالَ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يُسِرُّ إِلَيْكَ قَالَ فَغَضِبَ وَقَالَ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يُسِرُّ إِلَىَّ شَيْئًا يَكْتُمُهُ النَّاسَ غَيْرَ أَنَّهُ قَدْ حَدَّثَنِي بِكَلِمَاتٍ أَرْبَعٍ ‏.‏ قَالَ فَقَالَ مَا هُنَّ يَا أَمِيرَ الْمُؤْمِنِينَ قَالَ قَالَ ‏ "‏ لَعَنَ اللَّهُ مَنْ لَعَنَ وَالِدَهُ وَلَعَنَ اللَّهُ مَنْ ذَبَحَ لِغَيْرِ اللَّهِ وَلَعَنَ اللَّهُ مَنْ آوَى مُحْدِثًا وَلَعَنَ اللَّهُ مَنْ غَيَّرَ مَنَارَ الأَرْضِ ‏"‏ ‏.‏\hadithno{5124}\hadithtrans{Abu Tufail 'Amir b. Withila reported:I was in the company of 'Ali b. Abi Talib, when a person came to him, and said: What was it that Allah's Apostle (ﷺ) told you in secret? Thereupon he (liadrat 'All) was enraged and said: Allah's Apostle (ﷺ) did not tell me anything in secret that he hid from people, except that he told me four things. He said: Com- mader of Faithful, what are these? He said: Allah cursed him who cursed his father; Allah cursed him who sacrificed for anyone besides Allah; and Allah cursed him who accommodates an innovator (in religion) ; and Allah cursed him who changed the minarets (the boundary lines) of the land}}
\hadithdefcmd{muslim}{5125}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، سُلَيْمَانُ بْنُ حَيَّانَ عَنْ مَنْصُورِ، بْنِ حَيَّانَ عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْنَا لِعَلِيِّ بْنِ أَبِي طَالِبٍ أَخْبِرْنَا بِشَىْءٍ، أَسَرَّهُ إِلَيْكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا أَسَرَّ إِلَىَّ شَيْئًا كَتَمَهُ النَّاسَ وَلَكِنِّي سَمِعْتُهُ يَقُولُ ‏ "‏ لَعَنَ اللَّهُ مَنْ ذَبَحَ لِغَيْرِ اللَّهِ وَلَعَنَ اللَّهُ مَنْ آوَى مُحْدِثًا وَلَعَنَ اللَّهُ مَنْ لَعَنَ وَالِدَيْهِ وَلَعَنَ اللَّهُ مَنْ غَيَّرَ الْمَنَارَ ‏"‏ ‏.‏\hadithno{5125}\hadithtrans{Abu Tufail reported:We said to 'Ali b. Abi Talib: Inform us about something which Allah's Messenger (ﷺ) told you in secret, whereupon he said: He told me nothing in secret which he bid from people, but I heard him say: Allah cursed him who sacrificed for anyone besides Allah; and cursed him who accommodated an innovator; and Allah cursed him who cursed his parents and Allah cursed him who changed the boundary lines (of the land possessed by him)}}
\hadithdefcmd{muslim}{5126}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ أَبِي بَزَّةَ، يُحَدِّثُ عَنْ أَبِي الطُّفَيْلِ، قَالَ سُئِلَ عَلِيٌّ أَخَصَّكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ فَقَالَ مَا خَصَّنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ لَمْ يَعُمَّ بِهِ النَّاسَ كَافَّةً إِلاَّ مَا كَانَ فِي قِرَابِ سَيْفِي هَذَا - قَالَ - فَأَخْرَجَ صَحِيفَةً مَكْتُوبٌ فِيهَا ‏ "‏ لَعَنَ اللَّهُ مَنْ ذَبَحَ لِغَيْرِ اللَّهِ وَلَعَنَ اللَّهُ مَنْ سَرَقَ مَنَارَ الأَرْضِ وَلَعَنَ اللَّهُ مَنْ لَعَنَ وَالِدَهُ وَلَعَنَ اللَّهُ مَنْ آوَى مُحْدِثًا ‏"‏ ‏.‏\hadithno{5126}\hadithtrans{Abu Tufail reported:'Ali was asked whether Allah's Messenger (ﷺ) had showed special favour (by disclosing to him) a thing (which he kept secret from others). Thereupon he said: Allah's Messenger (ﷺ) singled us not for (disclosing to us) anything (secret) which he did not make public, (but those few things) which lie in the sheath of my sword. He drew out the written document contained in it and on that (it was mentioned): Allah cursed him who sacrificed for anyone else besides Allah; and Allah cursed him who stole the signposts (demarcating the boundary lines of the) land; and Allah cursed him who cursed his father; and Allah cursed him who accommodated an innovator (in religion)}}
